@@ -33,6 +33,7 @@ __all__ = [  # noqa
     "get_traceparent",
     "is_initialized",
     "isolation_scope",
+    "last_event_id",
     "new_scope",
     "push_scope",
     "set_context",
@@ -40,6 +41,7 @@ __all__ = [  # noqa
     "set_level",
     "set_measurement",
     "set_tag",
+    "set_tags",
     "set_user",
     "start_span",
     "start_transaction",
